import React, { useCallback } from 'react';
import { View, Image, TouchableOpacity, Text } from 'react-native';

import { AvatarWithInitials } from 'src/components';
import { API_HOST } from 'src/constants';
import { TriumphsStyles } from './styles';
import { TriumphsData } from '../utils/types';

export const TriumphItem = React.memo(
  ({ item, onPress }: { item: TriumphsData; onPress: (userId: number) => void }) => {
    const [firstPart, secondPart] = item.text.split(' reached ');
    const [firstName, lastName] = item.name.split(' ');

    const handlePress = useCallback(() => {
      onPress(item.user_id);
    }, [item.user_id, onPress]);

    return (
      <TouchableOpacity onPress={handlePress} style={TriumphsStyles.itemContainer}>
        {item.avatar ? (
          <View>
            <Image source={{ uri: API_HOST + item.avatar }} style={TriumphsStyles.avatar} />
            <Image source={{ uri: API_HOST + item.flag }} style={TriumphsStyles.flag} />
          </View>
        ) : (
          <AvatarWithInitials
            text={`${firstName[0] ?? ''}${lastName[0] ?? ''}`}
            flag={API_HOST + item.flag}
            size={48}
          />
        )}
        <View style={{ flex: 1 }}>
          <Text style={TriumphsStyles.text}>{item.name}</Text>
          <View style={{ flexDirection: 'row', flexWrap: 'wrap' }}>
            <Text style={TriumphsStyles.text}>
              <Text style={TriumphsStyles.reached}>reached </Text>
              <Text>{secondPart}</Text>
            </Text>
          </View>
        </View>

        <View style={TriumphsStyles.tresholdContainer}>
          <Image source={{ uri: API_HOST + item.icon }} style={TriumphsStyles.icon} />
          <Text style={TriumphsStyles.treshold}>{item.treshold}</Text>
        </View>
      </TouchableOpacity>
    );
  }
);
