import React from 'react';

import { Colors } from '../../../theme';
import { PageWrapper, MenuButton } from '../../../components';

import { MenuButtonType } from '../../../types/components';

import UserGroupIcon from '../../../../assets/icons/user-group.svg';
import CrownIcon from '../../../../assets/icons/crown.svg';
import IDCardIcon from '../../../../assets/icons/id-card.svg';
import StreetPeopleIcon from '../../../../assets/icons/street-view.svg';
import ChartPieIcon from '../../../../assets/icons/chart-pie.svg';
import MemoriamIcon from '../../../../assets/icons/monument.svg';
import ScrollIcon from '../../../../assets/icons/scroll.svg';
import TrophyIcon from '../../../../assets/icons/trophy.svg';

import { NAVIGATION_PAGES } from '../../../types';

const buttons: MenuButtonType[] = [
  {
    label: 'Master Ranking',
    icon: <UserGroupIcon fill={Colors.DARK_BLUE} width={20} height={20} />,
    buttonFn: (navigation) => {
      navigation.navigate(NAVIGATION_PAGES.MASTER_RANKING);
    }
  },
  {
    label: 'UN Masters',
    icon: <CrownIcon fill={Colors.DARK_BLUE} width={20} height={20} />,
    buttonFn: (navigation) => {
      navigation.navigate(NAVIGATION_PAGES.UN_MASTERS);
    }
  },
  {
    label: 'LPI Ranking',
    icon: <IDCardIcon fill={Colors.DARK_BLUE} width={20} height={20} />,
    buttonFn: (navigation) => {
      navigation.navigate(NAVIGATION_PAGES.LPI_RANKING);
    }
  },
  {
    label: 'Series Ranking',
    icon: <StreetPeopleIcon fill={Colors.DARK_BLUE} width={20} height={20} />
  },
  {
    label: 'Statistics',
    icon: <ChartPieIcon fill={Colors.DARK_BLUE} width={20} height={20} />,
    buttonFn: (navigation) => {
      navigation.navigate(NAVIGATION_PAGES.STATISTICS);
    }
  },
  {
    label: 'In Memoriam',
    icon: <MemoriamIcon fill={Colors.DARK_BLUE} width={20} height={20} />,
    buttonFn: (navigation) => {
      navigation.navigate(NAVIGATION_PAGES.IN_MEMORIAM);
    }
  },
  {
    label: 'In History',
    icon: <ScrollIcon fill={Colors.DARK_BLUE} width={20} height={20} />,
    buttonFn: (navigation) => {
      navigation.navigate(NAVIGATION_PAGES.IN_HISTORY);
    }
  },
  {
    label: 'Triumphs',
    icon: <TrophyIcon fill={Colors.DARK_BLUE} width={20} height={20} />,
    buttonFn: (navigation) => {
      navigation.navigate(NAVIGATION_PAGES.TRIUMPHS);
    }
  }
];

const TravellersScreen = () => {
  return (
    <PageWrapper>
      {buttons.map((button, index) => (
        <MenuButton
          label={button.label}
          icon={button.icon}
          buttonFn={button.buttonFn}
          key={'ranking-button-' + index}
        />
      ))}
    </PageWrapper>
  );
};

export interface Ranking {
  user_id: number;
  score_dare: number;
  score_nm: number;
  score_un: number;
  score_unp: number;
  score_tcc: number;
  score_deep: number;
  score_whs: number;
  score_kye: number;
  score_tbt: number;
  score_yes: number;
  score_slow: number;
  rank_tbt: number;
  avatar: string;
  first_name: string;
  last_name: string;
  age: number;
  flag1: string;
  flag2: string;
  badge_1281: number;
  badge_un: number;
  badge_supreme: number;
  badge_tbt: number;
  badge_offline: number;
  patreon: number;
  country: string;
  auth: number;
  rank: number;
  country_rank: number;
  dod: number;
  ukr: number;
  badges: number;
  arrow_nm: number;
  arrow_un: number;
  arrow_unp: number;
  arrow_dare: number;
  arrow_yes: number;
  arrow_whs: number;
  arrow_tcc: number;
  arrow_tbt: number;
  arrow_slow: number;
  arrow_kye: number;
}

export default TravellersScreen;
